Documentum Examples — pynexusic 2.5.0 documentation

# Documentum Examples

Example 1: Getting all repositories

> 1. Import `DOCUMENTUM_API`

>    >     from pynexusic import DOCUMENTUM_API as api

> 2. Initialize `DOCUMENTUM_API` class

>    >     doc_api = api.DOCUMENTUM_API(url, username=username, password=password, verbose=True)

> 3. Getting all repositories

>    >     repos = doc_api.get_repositories()

>    > Output:

>    >     repos = [{'id': 'xxxx', 'title': 'xxxx' ...}
>    >               ...
>    >             ]

Example 2: Getting a specific repositories

> 1. Import `DOCUMENTUM_API`

>          from pynexusic import DOCUMENTUM_API as api

> 2. Initialize `DOCUMENTUM_API` class

>    >     doc_api = api.DOCUMENTUM_API(url, username=username, password=password, verbose=True)

> 3. Getting a specific repositories

>    >     repo = doc_api.get_repository(repo_name)

>    where repo_name is the name of the repository to be extracted from Documentum

>    > Output:

>    >     repo = {'id': 'xxxx', 'title': 'xxxx' ...}